@@ -9,6 +9,7 @@
 #' @param n_cols the number of columns. This will only be used if mock data isn't
 #'   provided. If not supplied, it will default to using the `col_plan` from the
 #'   `tfrmt`. If neither are available it will use 3.
+#' @param .unicode_ws Whether to convert white space to unicode in preparation for output
 #'
 #' @return a stylized gt object
 #' @export
@@ -49,7 +50,11 @@
 #' @importFrom rlang quo_is_missing sym quo is_empty
 #' @importFrom dplyr vars
 #' @importFrom purrr quietly safely
-print_mock_gt <- function(tfrmt, .data = NULL, .default = 1:3, n_cols = NULL) {
+print_mock_gt <- function(tfrmt,
+                          .data = NULL,
+                          .default = 1:3,
+                          n_cols = NULL,
+                          .unicode_ws = TRUE) {
 
   # fill param, column if not provided
   if (quo_is_missing(tfrmt$param)){
@@ -84,7 +89,7 @@ print_mock_gt <- function(tfrmt, .data = NULL, .default = 1:3, n_cols = NULL) {
   }
 
   apply_tfrmt(.data, tfrmt, mock = TRUE) %>%
-    cleaned_data_to_gt(tfrmt)
+    cleaned_data_to_gt(tfrmt, .unicode_ws)
 
 }
 
@@ -92,6 +97,7 @@ print_mock_gt <- function(tfrmt, .data = NULL, .default = 1:3, n_cols = NULL) {
 #'
 #' @param tfrmt tfrmt object that will dictate the structure of the table
 #' @param .data Data to style in order to make the table
+#' @param .unicode_ws Whether to convert white space to unicode in preparation for output
 #'
 #' @return a stylized gt object
 #' @export
@@ -131,7 +137,7 @@ print_mock_gt <- function(tfrmt, .data = NULL, .default = 1:3, n_cols = NULL) {
 #'
 #' @importFrom gt gt tab_header tab_style cell_text cells_body tab_options
 #' @importFrom tidyselect everything
-print_to_gt <- function(tfrmt, .data){
+print_to_gt <- function(tfrmt, .data, .unicode_ws = TRUE){
   if(!is_tfrmt(tfrmt)){
     stop("Requires a tfrmt object")
   }
@@ -140,7 +146,7 @@ print_to_gt <- function(tfrmt, .data){
     stop("Requires data, if not avaliable please use `print_mock_gt()`")
   }
   apply_tfrmt(.data, tfrmt, mock = FALSE) %>%
-    cleaned_data_to_gt(tfrmt)
+    cleaned_data_to_gt(tfrmt, .unicode_ws)
 
 }
 
@@ -148,7 +154,7 @@ print_to_gt <- function(tfrmt, .data){
 #' Do all the formatting for the GT
 #' @rdname cleaned_data_to_gt
 #' @export
-cleaned_data_to_gt <- function(.data, tfrmt){
+cleaned_data_to_gt <- function(.data, tfrmt, .unicode_ws){
   UseMethod("cleaned_data_to_gt", .data)
 }
 
@@ -156,29 +162,35 @@ cleaned_data_to_gt <- function(.data, tfrmt){
 #'
 #' @param .data list of cleaned datasets
 #' @param tfrmt tfrmt
+#' @param .unicode_ws Whether to convert white space to unicode in preparation for output
 #'
 #' @return gt_group object
 #' @rdname cleaned_data_to_gt
 #' @export
+#'
+#' @keywords internal
 #' @importFrom gt gt_group
 #' @importFrom purrr map2
-cleaned_data_to_gt.list <- function(.data, tfrmt){
+cleaned_data_to_gt.list <- function(.data, tfrmt, .unicode_ws){
 
-  map(.data, ~cleaned_data_to_gt.default(.x, tfrmt)) %>%
+  map(.data, ~cleaned_data_to_gt.default(.x, tfrmt, .unicode_ws)) %>%
     gt_group(.list = .)
 }
 #' Apply formatting to a single table
 #'
 #' @param .data cleaned dataset
 #' @param tfrmt tfrmt
+#' @param .unicode_ws Whether to convert white space to unicode in preparation for output
 #'
 #' @return GT object
 #' @rdname cleaned_data_to_gt
 #' @export
+#'
+#' @keywords internal
 #' @importFrom gt cells_stub cells_row_groups default_fonts cell_borders
 #'   opt_table_font tab_options tab_style cell_text px cells_column_spanners
 #'   cells_body cells_column_labels md cols_hide sub_missing tab_stubhead
-cleaned_data_to_gt.default <- function(.data, tfrmt){
+cleaned_data_to_gt.default <- function(.data, tfrmt, .unicode_ws){
 
 
   if((is.null(tfrmt$row_grp_plan) ||(!inherits(.data, "grouped_df"))) && length(tfrmt$group) > 0){
@@ -205,7 +217,7 @@ cleaned_data_to_gt.default <- function(.data, tfrmt){
   }
   gt_out <- .data %>%
     gt(
-      rowname_col = as_label(tfrmt$label))  %>%
+      rowname_col = as_label(tfrmt$label)) %>%
     sub_missing(
       rows = .data$..tfrmt_row_grp_lbl==TRUE,
       missing_text = ""
@@ -337,6 +349,12 @@ cleaned_data_to_gt.default <- function(.data, tfrmt){
                  subtitle = tfrmt$subtitle)
   }
 
+  # convert white space to unicode
+  if (.unicode_ws){
+    gt_out_final <- gt_out_final %>%
+      convert_ws_unicode()
+  }
+
   # add footnotes and output
   gt_out_final %>%
     apply_footnote_plan(tfrmt,attr(.data,".footnote_locs"))
@@ -350,7 +368,7 @@ cleaned_data_to_gt.default <- function(.data, tfrmt){
 #' Makes a gt object and applies the spanning labels if relevant, as well as
 #' markdown formatting of all column labels
 #'
-#' @param .data dataset to convert to a gt
+#' @param gt_table gt object
 #' @param tfrmt tfrmt object
 #'
 #' @return gt object
@@ -417,3 +435,39 @@ format_gt_column_labels <- function(gt_table, .data){
 
 }
 
+#' Convert gt whitespace to unicode text
+#'
+#' @param gt_table gt object
+#'
+#' @return gt object
+#' @noRd
+#' @importFrom gt text_transform cells_body cells_stub cells_column_labels cells_column_spanners
+#' @importFrom stringr str_match str_c str_dup str_trim
+#'
+convert_ws_unicode <- function(gt_table){
+
+  locations <- list(cells_body())
+
+  if (!is.null(gt_table[["stub_df"]])){
+    locations <- c(locations,
+                   list(cells_stub()))
+  }
+
+  gt_table %>%
+    text_transform(
+      locations = locations,
+      fn = function(x) {
+
+        x_trimmed <- str_trim(x)
+        space_left <- str_match(x, "^\\s*") %>% nchar()
+        space_right <- str_match(x, "\\s*$") %>% nchar()
+        space_right[x_trimmed == ""] <- 0
+
+        str_c(
+          str_dup("\U00A0", space_left),
+          x_trimmed,
+          str_dup("\U00A0", space_right)
+        )
+      }
+    )
+}
