@@ -226,22 +226,24 @@ test_that("json body plan", {
           param2 = frmt_when(
             ">3" ~ frmt("(X.X%)"),
             "<=3" ~ frmt("Undetectable")
-          )
+          ),
+          missing = ""
         )
       ),
       frmt_structure(
         group_val = "test1",
         label_val = ".default",
-        foo = frmt("xx.x")
+        foo = frmt("xx.x", missing = "--")
       ),
       frmt_structure(
         group_val = ".default",
         label_val = ".default",
         frmt_when(
-          ">0.4" ~ frmt("(X.X%)"),
+          ">0.4" ~ frmt("(X.X%)", missing = ""),
           "<=0.4" ~ frmt_combine("[{par2m1}-{param2}]",
                                  param1 = frmt("XXX"),
-                                 param2 = frmt("XXX"))
+                                 param2 = frmt("XXX")),
+          missing = NULL
         )
       )
     )
